/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Карта"

, "Preferred Address"
: "Предпочтительный адрес"

, "Personal Information"
: "Личная  информация"

, "Salutation"
: "Приветствие"

, "Title"
: "Название"

, "Short Name"
: ""

, "First Name"
: "Имя"

, "Middle Name"
: "Второе имя"

, "Last Name"
: "Фамилия"

, "Company"
: "Фирма"

, "Unit"
: "Отделение"

, "Display Name"
: "Отображать как"

, "Industry, Industries"
: [
  ""
 ,""
 ,""
 ,""

]
, "Job Title"
: "Профессия"

, "Birthday (private)"
: ""

, "Contact Information"
: "Информация контакта"

, "Phone"
: "Телефон"

, "Mobile"
: "Мобильный телефон"

, "Fax"
: "Факс"

, "Phone (private)"
: "Телефон (личный)"

, "Mobile (private)"
: "Мобильный (личный)"

, "Fax (private)"
: "Факс (личный)"

, "E-Mail"
: "Электронная почта"

, "E-Mail (private)"
: "Электронная почта (личная)"

, "Web"
: "Интернет"

, "Company Address"
: "Адрес фирмы"

, "Street"
: "Улица"

, "Street 2"
: "Следующая улица"

, "Region"
: "Область"

, "Postal Code"
: "Почтовый индекс"

, "City"
: "Город"

, "Country"
: "Страна"

, "Private Address"
: "Личный адрес"

, "Description"
: "Описание"

, "Enter description"
: "Введите описание"

, "Groups"
: "Группы"

, "Parse address"
: "Синтаксический анализ адреса"

, "Print contact"
: "Печать контакта"

, "Paste address"
: "Вставит адрес"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Пожалуйста, укажите адрес или URI для vcard, который можно разобрать:"

, "Failed to parse address!"
: "Невозможно разобрать адрес"

, "The address could not be read."
: "Адрес нечитаем"

, "End token mode"
: "Окончание действия символьного отпечатка"

, "Customfields"
: "Настраиваемые поля"

, "Related to"
: "Относится к"

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: "Поиск системных групп..."

, "Search for groups ..."
: "Поиск групп..."

, "Contact, Contacts"
: [
  "Контакт"
 ,"Контакта"
 ,"Контактов"
 ,"Контактов"

]
, "Members"
: "Участники"

, "Search for members ..."
: ""

, "List Roles"
: "Список ролей"

, "Remove Member"
: "Удалить члена"

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "Новый контакт"

, "Addressbook, Addressbooks"
: [
  "Адресная книга"
 ,"Адресные книги"
 ,"Адресные книги"
 ,"Адресные книги"

]
, "ID"
: "ID"

, "Name"
: "Имя"

, "Structure, Structures"
: [
  ""
 ,""
 ,""
 ,""

]
, "Resources"
: "Ресурсы"

, "Private"
: "Личное"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "List Information"
: "Информация о списке"

, "List type"
: "Список типов"

, "System accounts only"
: ""

, "{0} must be given"
: "{0} должен быть задан"

, "List Functions"
: ""

, "Suffix"
: "Дополнение имени"

, "Birthday"
: "Дата рождения"

, "Job Role"
: "Рабочая роль"

, "Room"
: "Помещение"

, "Street (Company Address)"
: "Улица (рабочий адрес)"

, "Street 2 (Company Address)"
: "Улица2 (рабочий адрес)"

, "City (Company Address)"
: "Город (рабочий адрес)"

, "Region (Company Address)"
: "Регион (рабочий адрес)"

, "Postal Code (Company Address)"
: "Индекс (рабочий адрес)"

, "Country (Company Address)"
: "Страна (рабочий адрес)"

, "Longitude (Company Address)"
: "Долгота (рабочий адрес)"

, "Latitude (Company Address)"
: "Широта (рабочий адрес)"

, "Street (Private Address)"
: "Улица (личный адрес)"

, "Street 2 (Private Address)"
: "Улица2 (личный адрес)"

, "City (Private Address)"
: "Город (личный адрес)"

, "Region (Private Address)"
: "Регион (личный адрес)"

, "Postal Code (Private Address)"
: "Индекс (личный адрес)"

, "Country (Private Address)"
: "Страна (личный адрес)"

, "Company Communication"
: "Корпоративное сообщение"

, "Private Communication"
: "Частное сообщение"

, "Web (private)"
: "Сайт (личный)"

, "Contacts"
: "Контакты"

, "Addressbooks"
: "Адресные книги"

, "User Account"
: "Учётная запись преподавателя"

, "Quick Search"
: "Быстрый поиск"

, "Type"
: "Тип"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение"

, "Creation Time"
: "Время создания"

, "Created By"
: "Создано "

, "List, Lists"
: [
  "Список"
 ,"Списки"
 ,"Списки"
 ,"Списки"

]
, "Lists"
: "Списки"

, "Email Address, Email Addresses"
: [
  "Адрес электронной почты"
 ,"Адреса электронной почты"
 ,"Адреса электронной почты"
 ,"Адреса электронной почты"

]
, "Email Addresses"
: "Адреса электронной почты"

, "Quick search"
: "Быстрый поиск"

, "List Function, List Functions"
: [
  ""
 ,""
 ,""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: "Отрасли промышленности"

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Импорт контактов"

, "Contact of a user account"
: "Контакт пользователя"

, "No name"
: "Без имени"

, "Not set"
: "Не установлено"

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Тэги"

, "Full Name"
: "Полное имя"

, "Postalcode"
: "Почтовый индекс"

, "Street (private)"
: "Улица (личная)"

, "City (private)"
: "Город (личный)"

, "Region (private)"
: "Область (личная)"

, "Postalcode (private)"
: "Почтовый индекс (личный)"

, "Country (private)"
: "Страна (личная)"

, "Email"
: "Электронная почта"

, "Car phone"
: "Автомобильный телефон"

, "Pager"
: "Пейджер"

, "Email (private)"
: "Электронная почта (личная)"

, "URL (private)"
: "Личный веб-сайт"

, "Note"
: "Заметка"

, "Timezone"
: "Часовой пояс"

, "Geo"
: "Координаты"

, "Select list"
: "Выберите список"

, "Search for users ..."
: "Поиск пользователей..."

, "Search for Contacts ..."
: "Поиск контактов..."

, "Company address"
: "Рабочий адрес"

, "Private address"
: "Личный адрес"

, "Member E-Mails"
: ""

, "System Group"
: "Системная группа"

, "Group"
: "Группа"

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Все контакты"

, "Default Addressbook"
: "Адресная книга по умолчанию"

, "The default addressbook for new contacts"
: "Адресная книга по умолчанию для новых контактов"

, "Default Favorite"
: "Избранный по умолчанию"

, "The default favorite which is loaded on addressbook startup"
: "Показывать по-умолчанию при загрузке адресной книги"

, "Contacts ODS export configuration"
: "Конфигурация экспорта контактов в ODS"

, "Use this configuration for the contact ODS export."
: "Использовать эти настройки для экспорта контактов в ODS"

, "Contacts XLS export configuration"
: "Конфигурация экспорта контактов в XLS"

, "Use this configuration for the contact XLS export."
: "Использовать эти настройки для экспорта контактов в XLS"

, "default"
: "по умолчанию"

, "Enabled Features"
: "Активные возможности"

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: "Вид адресной книги"

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: "Добавить поле \"Отрасль промышленности\" в Адресную книгу"

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: "Управление ресурсами в адресной книге"

, "Show the resources grid also inside the Addressbook"
: "Показывать сетку ресурсов внутри Адресной книги"

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Поля для проверки дублирования контактов"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Эти поля проверяются при создании нового контакта. Если запись с таким же данным в полях найдена, выводится предложение исключить дубликат."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Доступны приветствия контакта"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Возможные приветствия контакта. Обратите внимание, что дополнительные значения могут повлиять на другие системы адресных книг при экспорте или синхронизации."

, "Mr"
: "Господин"

, "Ms"
: "Госпожа"

, "Parsing rules for addresses"
: "Синтаксический анализ правил для адресов"

, "Path to a XML file with address parsing rules."
: "Путь к XML файлу с правилами разбора адреса."

, "List types available"
: "Список доступных типов"

, "List types available."
: "Список доступных типов."

, "Department"
: "Отдел"

, "Mailing list"
: "Список рассылки"

, "Use Nominatim during contact import"
: "Использовать Nominatim при импорте контактов"

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: "Модули синхронизации"

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s личная адресная книга"

, "Business Contact Data"
: "Деловые данные контактов"

, "Organisation / Unit"
: "Организация / Отделение"

, "Business Address"
: "Рабочий адрес"

, "Telephone Work"
: "Телефон (рабочий)"

, "Telephone Cellphone"
: "Телефон (мобильный)"

, "Telephone Car"
: "Телефон (автомобильный)"

, "Telephone Fax"
: "Телефон (факс)"

, "Telephone Page"
: "Пейджер"

, "URL"
: "URL"

, "Role"
: "Роль"

, "Assistant"
: "Помощник"

, "Assistant Telephone"
: "Телефон помощника"

, "Private Contact Data"
: "Личные данные контактов"

, "Email Home"
: "Электронная почта"

, "Telephone Home"
: "Телефон"

, "Telephone Cellphone Private"
: "Личный сотовый телефон"

, "Telephone Fax Home"
: "Факс (домашний)"

, "URL Home"
: "Домашний URL"

, "Other Data"
: "Другие данные"

, "OpenDocument all data"
: "Экспорт всех данных в OpenDocument"

, "Excel phone list"
: "Экспорт списка телефонов в Excel"

, "Excel phone list grouped by company"
: "Экспорт в Excel списка телефонов сгруппированного по компаниям"

, "Word details"
: "Экспорт подробностей в Word"

, "Excel overview"
: "Экспорт сводки в Excel"

, "Word letter"
: "Экспорт письма в Word"

, "PDF details"
: "Экспорт в PDF"

, "Excel all data"
: "Экспорт данных в Excel"

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: "Экспорт данных в формате CSV"

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: "Импорт контактов CSV из адресной книги Exchange/Outlook"

, "Contact CSV import from Outlook address book"
: "Импорт контактов CSV из адресной книги Outlook"

, "Contact CSV import from mac address book"
: "Импорт контактов CSV из адресной книги mac"

, "Import CSV formated contacts from Outlook 2007 German address book"
: "Импорт контактов CSV из адресной книги немецкой версии Outlook 2007"

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 (немецкий)"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: "Импорт контактов в формате vCard"

, "Contact VCARD import"
: "Импорт контактов VCARD"

, "LX-Office CSV Contact import"
: "Импорт контактов CSV LX-Office"

, "Import CSV formated contacts from LX-Office"
: "Импорт контактов CSV из LX-Office"

, "Tine 2.0 contact CSV import"
: "Импорт контактов CSV Tine 2.0"

, "Import CSV formated contacts from Tine 2.0 address book"
: "Импорт контактов CSV из адресной книги Tine 2.0"

, "Import list (###CURRENTDATE###)"
: "Импорт списка (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Контакты импортированы ###CURRENTDATE### в ###CURRENTTIME### ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: "Импорт контактов CSV из адресной книги Google"

, "Contact import from Google address book"
: "Импорт контактов CSV из адресной книги Google"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Внутренние контакты"

, "All contacts I have read grants for"
: "Все контакты, для которых у меня есть право чтения"

, "My company"
: "Моя компания"

, "All coworkers in my company"
: "Все коллеги в моей компании"

, "My contacts"
: "Мои контакты"

, "All contacts in my Addressbooks"
: "Все контакты в моих адресных книгах"

, "Last modified by me"
: "Мои последние изменения"

, "All contacts that I have last modified"
: "Все контакты, которые последним редактировал я"

, "All Contacts"
: "Все контакты"

, "This contact has been automatically added by the system as an event attender"
: "Этот контакт был автоматически добавлен системой"

, "manage shared addressbooks"
: "управлять общими адресными книгами"

, "Create new shared addressbook folders"
: "Создать новую общую папку адресной книги"

, "manage shared addressbook favorites"
: "управлять избранным в общих адресных книгах"

, "Create or update shared addressbook favorites"
: "Создание или обновление избранных в общих адресных книгах"

, "Manage lists in CoreData"
: "Управлять списками в основном приложении"

, "View, create, delete or update lists in CoreData application"
: "Просмотр, создание, удаление и обновление списков в основном приложении"

, "Manage list functions in CoreData"
: "Управление функциями списка в основном приложении"

, "View, create, delete or update list functions in CoreData application"
: "Просмотр, создание, удаление и обновление функций списка в основном приложении"

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Контакт"

, "Addressbook"
: "Адресная книга"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Список"

, "Email Address"
: "Адрес электронной почты"

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
